#' @export
#' @importFrom bayestestR simulate_simpson
bayestestR::simulate_simpson

#' @export
#' @importFrom datawizard visualisation_recipe
datawizard::visualisation_recipe

#' @export
#' @importFrom insight standardize_names
insight::standardize_names

#' @importFrom insight print_md
#' @export
insight::print_md

#' @importFrom insight print_html
#' @export
insight::print_html

#' @importFrom insight display
#' @export
insight::display
